# alchy

[![Package Version](https://pypip.in/v/alchy/badge.png?v=0.10.0)](https://pypi.python.org/pypi/alchy/)
[![Build Status](https://travis-ci.org/dgilland/alchy.png?branch=master)](https://travis-ci.org/dgilland/alchy)
[![Coverage Status](https://coveralls.io/repos/dgilland/alchy/badge.png?branch=master)](https://coveralls.io/r/dgilland/alchy)
[![License](https://pypip.in/license/alchy/badge.png)](https://pypi.python.org/pypi/alchy/)

Enhancement library for SQLAlchemy

[Documentation](http://dgilland.github.io/alchy)
